#
# spec file for package ansible-navigator
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%if 0%{?suse_version} < 1550
# Leap15, SLES15
%if %pythons == "python310"
%define ansible_python python310
%define ansible_python_executable python3.10
%define ansible_python_sitelib %python310_sitelib
%endif
%if %pythons == "python311"
%define ansible_python python311
%define ansible_python_executable python3.11
%define ansible_python_sitelib %python311_sitelib
%endif
%else
# Tumbleweed
%define pythons python3
%define ansible_python python3
%define ansible_python_executable python3
%define ansible_python_sitelib %python3_sitelib
%endif

Name:           ansible-navigator
Version:        24.10.0
Release:        1.1
Summary:        A text-based user interface (TUI) for Ansible
License:        Apache-2.0
URL:            https://github.com/ansible/ansible-navigator
Source:         ansible-navigator-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  %{ansible_python}-base >= 3.10
BuildRequires:  %{ansible_python}-pip
BuildRequires:  %{ansible_python}-pip-wheel
# https://github.com/ansible/ansible-navigator/blob/main/.config/requirements.in#L8
BuildRequires:  %{ansible_python}-setuptools >= 63.1.0
BuildRequires:  %{ansible_python}-setuptools_scm >= 7.0
BuildRequires:  %{ansible_python}-tzdata
BuildRequires:  %{ansible_python}-wheel
BuildRequires:  python-rpm-macros
# Use Requires also as BuildRequires
# to make sure we only build, if everything needed is present
# https://github.com/ansible/ansible-navigator/blob/main/.config/requirements.in
BuildRequires:  %{ansible_python}-Jinja2
BuildRequires:  %{ansible_python}-PyYAML
BuildRequires:  %{ansible_python}-jsonschema
BuildRequires:  %{ansible_python}-onigurumacffi >= 1.1.0
BuildRequires:  %{ansible_python}-pytzdata
BuildRequires:  %{ansible_python}-requirements-parser
BuildRequires:  ansible-builder >= 3.0.0
BuildRequires:  ansible-core >= 2.14.3
BuildRequires:  ansible-lint >= 6.19.0
BuildRequires:  ansible-runner >= 2.3.2
# SECTION test requirements
# https://github.com/ansible/ansible-navigator/blob/main/test/requirements.txt
BuildRequires:  %{ansible_python}-pytest
BuildRequires:  %{ansible_python}-libtmux
BuildRequires:  tmux
# /SECTION
BuildRequires:  git-core
BuildRequires:  fdupes
# https://github.com/ansible/ansible-navigator/blob/main/.config/requirements.in
Requires:       %{ansible_python}-Jinja2
Requires:       %{ansible_python}-PyYAML
Requires:       %{ansible_python}-curses
Requires:       %{ansible_python}-jsonschema
Requires:       %{ansible_python}-onigurumacffi >= 1.1.0
Requires:       %{ansible_python}-pytzdata
Requires:       %{ansible_python}-setuptools
Requires:       ansible-builder >= 3.0.0
Requires:       ansible-core >= 2.14.3
Requires:       ansible-lint >= 6.19.0
Requires:       ansible-runner >= 2.3.2
Requires:       (podman or docker)
Suggests:       %{ansible_python}-importlib-metadata
Suggests:       %{ansible_python}-mkdocs-ansible >= 0.1.2
Suggests:       %{ansible_python}-darglint
Suggests:       %{ansible_python}-libtmux
Suggests:       %{ansible_python}-pre-commit

%description
A text-based user interface (TUI) for Ansible.

When running ansible-navigator with no arguments, you will be presented with the welcome page. From this page, you can run playbooks, browse collections, explore inventories, read Ansible documentation, and more.

A full list of key bindings can be viewed by typing :help.

%prep
%setup -q -n ansible-navigator-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{ansible_python_sitelib}

%files
%doc README.md
%license LICENSE
%{_bindir}/ansible-navigator
%{ansible_python_sitelib}/ansible_navigator
%{ansible_python_sitelib}/ansible_navigator-%{version}.dist-info/

%changelog
* Wed Nov 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.10.0:
  * Enhancements
  - Add support for py313 (#1871) @abhikdps
  * Bugfixes
  - Allow images subcommand to display the resulting output in
    JSON format (#1872) @shatakshiiii
* Thu Sep 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.9.0:
  * Enhancements
  - Community comms (#1843) @oraNod
  * Bugfixes
  - Fix upload-artifact action to work with v4.4 and newer
    (#1846) @alisonlhart
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.8.0:
  * Bump coactions/dynamic-matrix from 1 to 2 (#1833)
  * [pre-commit.ci] pre-commit autoupdate (#1835)
  * Bump the dependencies group in /.config with 10 updates (#1832)
  * Fix CI test failures: Remove unused `bindep.txt` (#1834)
  * [pre-commit.ci] pre-commit autoupdate (#1831)
  * Bump the dependencies group in /.config with 6 updates (#1830)
  * [pre-commit.ci] pre-commit autoupdate (#1829)
  * Bump the dependencies group in /.config with 9 updates (#1827)
  * Update to match common extensions. (#1826)
  * Update codeowners (#1825)
  * Update CoC to match other repositories. (#1824)
  * Add sonarcloud config (#1823)
  * [pre-commit.ci] pre-commit autoupdate (#1822)
  * Bump the dependencies group in /.config with 5 updates (#1821)
  * [pre-commit.ci] pre-commit autoupdate (#1812)
  * Adopt community-ansible-dev-tools image (#1819)
  * Bump the dependencies group in /.config with 10 updates (#1820)
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.7.0:
  * Updated cspell dictionary and removed unneeded values (#1817)
  * Bump the dependencies group in /.config with 4 updates (#1816)
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.1:
  * Bugfixes
  - Exit with an appropriate message if the image is invalid
    (#1810) @shatakshiiii
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.6.0:
  * Fix the documentation for securely passing the vault password
    (#1799)
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.3.2:
  * Fix python version in release workflow (#1748)
* Tue Apr 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 24.3.1:
  * Bump the dependencies group across 1 directory with 18 updates
    (#1743)
  * Update GHA repo ref (#1745)
  * Update the version of collection doc cache (#1739)
  * Fix catalog collections script to display all available modules
    in a collection (#1738)
  * [pre-commit.ci] pre-commit autoupdate (#1742)
  * [pre-commit.ci] pre-commit autoupdate (#1737)
  * Bump the dependencies group in /.config with 7 updates (#1735)
* Wed Apr 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.3.0:
  * Minor Changes
  - Update creator-ee to 24.2.0 (#1683) @shatakshiiii
  - Drop support to Python 3.9 (#1670) @cristianonicolai
  * Bugfixes
  - Test suite: Support for libtmux 0.30.1+ (#1687) @tony
  - drop setuptools_scm_git_archive (#1716) @jose1711
  - Fix conditional import compatibility (#1666) @NilashishC
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.2.0:
  * Minor Changes
  - Update creator-ee to 0.22.0 (#1656) @shatakshiiii
  * Bugfixes
  - Update cmdline description (#1657) @shatakshiiii
- update to 3.6.0:
  * Minor Changes
  - Update creator-ee to 0.21.0 (#1650) @shatakshiiii
  * Bugfixes
  - Address DTZ rule (#1626) @shatakshiiii
- update to 3.5.0:
  * Minor Changes
  - Update creator-ee to 0.20.0 (#1567) @shatakshiiii
  * Bugfixes
  - Expand env variable mentioned in the pull arguments (--pa)
    (#1590) @shatakshiiii
  - Add tests for lint, without an EE (#1574) @shatakshiiii
  - Include documentation URL in JSON Schema (#1596) @ssbarnea
- update to 3.4.2:
  * Bugfixes
  - Change the python_exec path to /usr/bin/python3 (#1587)
    @shatakshiiii
  - Fix image introspect for PythonPackages (#1585) @shatakshiiii
- update to 3.4.1:
  * Bugfixes
  - Add EE Getting started references to docs (#1576)
    @Andersson007
  - Remove the introspect script from image_manager directory
    (#1561) @shatakshiiii
  - Fix image introspect for long python metadata (#1555)
    @shatakshiiii
  - Fix logging dependencies (#1554) @shatakshiiii
- update to 3.4.0:
  * Minor Changes
  - Update creator-ee version to 0.18.0 (#1542) @shatakshiiii
  * Bugfixes
  - Fix collections in stdout mode (#1526) @shatakshiiii
- update to 3.3.1:
  * Bugfixes
  - Set user to root with podman (#1539) @cidrblock
  - Fix building of dynamic configuration section (#1538)
    @ssbarnea
  - Display sidecar plugin in the collections list (#1531)
    @shatakshiiii
- update to 3.3.0:
  * Minor Changes
  - Update ansible-builder version (#1530) @shatakshiiii
  - Test sidecar filter plugin doc (#1522) @shatakshiiii
  * Bugfixes
  - Add support for all plugin_types (#1515) @shatakshiiii
  - Include only major version inside schema generation (#1513)
    @shatakshiiii
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- switch to Github tarball created by OBS service
* Wed May 31 2023 Johannes Kastl <kastl@b1-systems.de>
- fix wrong tarball by redownloading
* Tue May 30 2023 Johannes Kastl <kastl@b1-systems.de>
- fix version reporting and do not use glob for file list
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- modify %%if-condition to allow building for python3.10 or
  python3.11 on SLES15
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- change python version on Leap15/SLES15 to python3.11 to use the
  new stack supported by SUSE
* Mon May  1 2023 Johannes Kastl <kastl@b1-systems.de>
- new package ansible-navigator: A text-based user interface (TUI)
  for Ansible
